#Wallpapers

This is a library to generate wallpapers based on a pattern provided through
a file. Here are the 17 generated plane groups shown as examples :

![](figures/p1.png)
![](figures/p2.png)
![](figures/p1m1.png)
![](figures/p1g1.png)
![](figures/c1m1.png)
![](figures/c2mm.png)
![](figures/p2mm.png)
![](figures/p2mg.png)
![](figures/p2gg.png)
![](figures/p4.png)
![](figures/p4mm.png)
![](figures/p4gm.png)
![](figures/p3.png)
![](figures/p31m.png)
![](figures/p31m.png)
![](figures/p6.png)
![](figures/p6mm.png)
